summaryrefslogtreecommitdiffstats
path: root/win/CS
diff options
context:
space:
mode:
authorsr55 <[email protected]>2015-05-16 20:36:53 +0000
committersr55 <[email protected]>2015-05-16 20:36:53 +0000
commitbec7d3d5986a4845fd5c7cccf88de40e4b6e2c74 (patch)
treeb75379b29ff0f5587cc0c19ca67cf2ae3769f1f4 /win/CS
parent57407c6b045b7a82a5bdf764ea94fcd80f262869 (diff)
WinGui: Update the libhb preset stubs.
git-svn-id: svn://svn.handbrake.fr/HandBrake/trunk@7198 b64f7644-9d1e-0410-96f1-a4d463321fa5
Diffstat (limited to 'win/CS')
-rw-r--r--win/CS/HandBrake.ApplicationServices/Interop/HandBrakeInstanceManager.cs29
-rw-r--r--win/CS/HandBrake.ApplicationServices/Interop/HandBrakePresetService.cs2
-rw-r--r--win/CS/HandBrake.ApplicationServices/Interop/Json/Encode/Chapter.cs28
-rw-r--r--win/CS/HandBrake.ApplicationServices/Interop/Json/Encode/SubtitleTrack.cs88
-rw-r--r--win/CS/HandBrake.ApplicationServices/Interop/Json/Encode/Subtitles.cs10
-rw-r--r--win/CS/HandBrake.ApplicationServices/Interop/Json/Presets/AudioList.cs32
-rw-r--r--win/CS/HandBrake.ApplicationServices/Interop/Json/Presets/Preset.cs240
-rw-r--r--win/CS/HandBrake.ApplicationServices/Interop/Json/Presets/PresetCategory.cs7
-rw-r--r--win/CS/HandBrakeWPF/ViewModels/VideoViewModel.cs2
9 files changed, 301 insertions, 137 deletions
diff --git a/win/CS/HandBrake.ApplicationServices/Interop/HandBrakeInstanceManager.cs b/win/CS/HandBrake.ApplicationServices/Interop/HandBrakeInstanceManager.cs
index 7a2e93d1b..aee941447 100644
--- a/win/CS/HandBrake.ApplicationServices/Interop/HandBrakeInstanceManager.cs
+++ b/win/CS/HandBrake.ApplicationServices/Interop/HandBrakeInstanceManager.cs
@@ -21,6 +21,24 @@ namespace HandBrake.ApplicationServices.Interop
{
private static HandBrakeInstance scanInstance;
private static HandBrakeInstance encodeInstance;
+ private static HandBrakeInstance masterInstance;
+
+ /// <summary>
+ /// Initializes static members of the <see cref="HandBrakeInstanceManager"/> class.
+ /// </summary>
+ static HandBrakeInstanceManager()
+ {
+ masterInstance = new HandBrakeInstance();
+ masterInstance.Initialize(2);
+ }
+
+ /// <summary>
+ /// The init.
+ /// </summary>
+ public static void Init()
+ {
+ // Nothing to do. Triggers static constructor.
+ }
/// <summary>
/// Gets the scanInstance.
@@ -71,6 +89,17 @@ namespace HandBrake.ApplicationServices.Interop
}
/// <summary>
+ /// Gets the master instance.
+ /// </summary>
+ public static IHandBrakeInstance MasterInstance
+ {
+ get
+ {
+ return masterInstance;
+ }
+ }
+
+ /// <summary>
/// Gets the last scan scan instance.
/// </summary>
public static IHandBrakeInstance LastScanScanInstance
diff --git a/win/CS/HandBrake.ApplicationServices/Interop/HandBrakePresetService.cs b/win/CS/HandBrake.ApplicationServices/Interop/HandBrakePresetService.cs
index d49d789c8..0fdf95211 100644
--- a/win/CS/HandBrake.ApplicationServices/Interop/HandBrakePresetService.cs
+++ b/win/CS/HandBrake.ApplicationServices/Interop/HandBrakePresetService.cs
@@ -30,7 +30,7 @@ namespace HandBrake.ApplicationServices.Interop
/// </summary>
static HandBrakePresetService()
{
- HBFunctions.hb_presets_builtin_init();
+ HandBrakeInstanceManager.Init();
}
/// <summary>
diff --git a/win/CS/HandBrake.ApplicationServices/Interop/Json/Encode/Chapter.cs b/win/CS/HandBrake.ApplicationServices/Interop/Json/Encode/Chapter.cs
index 567d0e7a3..95eeb0057 100644
--- a/win/CS/HandBrake.ApplicationServices/Interop/Json/Encode/Chapter.cs
+++ b/win/CS/HandBrake.ApplicationServices/Interop/Json/Encode/Chapter.cs
@@ -5,18 +5,18 @@
// <summary>
// Represents a chapter to encode.
// </summary>
-// --------------------------------------------------------------------------------------------------------------------
-
-namespace HandBrake.ApplicationServices.Interop.Json.Encode
-{
- /// <summary>
- /// Represents a chapter to encode.
- /// </summary>
- public class Chapter
- {
- /// <summary>
- /// Gets or sets the name.
- /// </summary>
- public string Name { get; set; }
- }
+// --------------------------------------------------------------------------------------------------------------------
+
+namespace HandBrake.ApplicationServices.Interop.Json.Encode
+{
+ /// <summary>
+ /// Represents a chapter to encode.
+ /// </summary>
+ public class Chapter
+ {
+ /// <summary>
+ /// Gets or sets the name.
+ /// </summary>
+ public string Name { get; set; }
+ }
} \ No newline at end of file
diff --git a/win/CS/HandBrake.ApplicationServices/Interop/Json/Encode/SubtitleTrack.cs b/win/CS/HandBrake.ApplicationServices/Interop/Json/Encode/SubtitleTrack.cs
index af4ece97e..929c001d0 100644
--- a/win/CS/HandBrake.ApplicationServices/Interop/Json/Encode/SubtitleTrack.cs
+++ b/win/CS/HandBrake.ApplicationServices/Interop/Json/Encode/SubtitleTrack.cs
@@ -5,48 +5,48 @@
// <summary>
// Represents a subtitle track to encode.
// </summary>
-// --------------------------------------------------------------------------------------------------------------------
-
-namespace HandBrake.ApplicationServices.Interop.Json.Encode
-{
- /// <summary>
- /// Represents a subtitle track to encode.
- /// </summary>
- public class SubtitleTrack
- {
- /// <summary>
- /// Gets or sets a value indicating whether burn.
- /// </summary>
- public bool Burn { get; set; }
-
- /// <summary>
- /// Gets or sets a value indicating whether default.
- /// </summary>
- public bool Default { get; set; }
-
- /// <summary>
- /// Gets or sets a value indicating whether force.
- /// </summary>
- public bool Forced { get; set; }
-
- /// <summary>
- /// Gets or sets the id.
- /// </summary>
- public int ID { get; set; }
-
- /// <summary>
- /// Gets or sets the offset.
- /// </summary>
- public int Offset { get; set; }
-
- /// <summary>
- /// Gets or sets the track.
- /// </summary>
- public int Track { get; set; }
-
- /// <summary>
- /// Gets or sets the srt.
- /// </summary>
- public SRT SRT { get; set; }
- }
+// --------------------------------------------------------------------------------------------------------------------
+
+namespace HandBrake.ApplicationServices.Interop.Json.Encode
+{
+ /// <summary>
+ /// Represents a subtitle track to encode.
+ /// </summary>
+ public class SubtitleTrack
+ {
+ /// <summary>
+ /// Gets or sets a value indicating whether burn.
+ /// </summary>
+ public bool Burn { get; set; }
+
+ /// <summary>
+ /// Gets or sets a value indicating whether default.
+ /// </summary>
+ public bool Default { get; set; }
+
+ /// <summary>
+ /// Gets or sets a value indicating whether force.
+ /// </summary>
+ public bool Forced { get; set; }
+
+ /// <summary>
+ /// Gets or sets the id.
+ /// </summary>
+ public int ID { get; set; }
+
+ /// <summary>
+ /// Gets or sets the offset.
+ /// </summary>
+ public int Offset { get; set; }
+
+ /// <summary>
+ /// Gets or sets the track.
+ /// </summary>
+ public int Track { get; set; }
+
+ /// <summary>
+ /// Gets or sets the srt.
+ /// </summary>
+ public SRT SRT { get; set; }
+ }
} \ No newline at end of file
diff --git a/win/CS/HandBrake.ApplicationServices/Interop/Json/Encode/Subtitles.cs b/win/CS/HandBrake.ApplicationServices/Interop/Json/Encode/Subtitles.cs
index 13439eaa7..248801789 100644
--- a/win/CS/HandBrake.ApplicationServices/Interop/Json/Encode/Subtitles.cs
+++ b/win/CS/HandBrake.ApplicationServices/Interop/Json/Encode/Subtitles.cs
@@ -21,9 +21,9 @@ namespace HandBrake.ApplicationServices.Interop.Json.Encode
/// </summary>
public SubtitleSearch Search { get; set; }
- /// <summary>
- /// Gets or sets the subtitle list.
- /// </summary>
- public List<SubtitleTrack> SubtitleList { get; set; }
- }
+ /// <summary>
+ /// Gets or sets the subtitle list.
+ /// </summary>
+ public List<SubtitleTrack> SubtitleList { get; set; }
+ }
} \ No newline at end of file
diff --git a/win/CS/HandBrake.ApplicationServices/Interop/Json/Presets/Preset.cs b/win/CS/HandBrake.ApplicationServices/Interop/Json/Presets/Preset.cs
index a90410c54..8d19d0ae3 100644
--- a/win/CS/HandBrake.ApplicationServices/Interop/Json/Presets/Preset.cs
+++ b/win/CS/HandBrake.ApplicationServices/Interop/Json/Presets/Preset.cs
@@ -12,54 +12,54 @@ namespace HandBrake.ApplicationServices.Interop.Json.Presets
using System.Collections.Generic;
/// <summary>
- /// The preset.
+ /// The preset.
/// </summary>
public class Preset
{
/// <summary>
- /// Gets or sets the audio allow aac pass.
+ /// Gets or sets the audio copy mask.
/// </summary>
- public int AudioAllowAACPass { get; set; }
+ public List<object> AudioCopyMask { get; set; }
/// <summary>
- /// Gets or sets the audio allow a c 3 pass.
+ /// Gets or sets the audio encoder fallback.
/// </summary>
- public int AudioAllowAC3Pass { get; set; }
+ public string AudioEncoderFallback { get; set; }
/// <summary>
- /// Gets or sets the audio allow dtshd pass.
+ /// Gets or sets the audio language list.
/// </summary>
- public int AudioAllowDTSHDPass { get; set; }
+ public List<string> AudioLanguageList { get; set; }
/// <summary>
- /// Gets or sets the audio allow dts pass.
+ /// Gets or sets the audio list.
/// </summary>
- public int AudioAllowDTSPass { get; set; }
+ public List<AudioList> AudioList { get; set; }
/// <summary>
- /// Gets or sets the audio allow m p 3 pass.
+ /// Gets or sets a value indicating whether audio secondary encoder mode.
/// </summary>
- public int AudioAllowMP3Pass { get; set; }
+ public bool AudioSecondaryEncoderMode { get; set; }
/// <summary>
- /// Gets or sets the audio encoder fallback.
+ /// Gets or sets the audio track selection behavior.
/// </summary>
- public string AudioEncoderFallback { get; set; }
+ public string AudioTrackSelectionBehavior { get; set; }
/// <summary>
- /// Gets or sets the audio list.
+ /// Gets or sets a value indicating whether chapter markers.
/// </summary>
- public List<AudioList> AudioList { get; set; }
+ public bool ChapterMarkers { get; set; }
/// <summary>
- /// Gets or sets the chapter markers.
+ /// Gets or sets the children array.
/// </summary>
- public int ChapterMarkers { get; set; }
+ public List<object> ChildrenArray { get; set; }
/// <summary>
- /// Gets or sets the default.
+ /// Gets or sets a value indicating whether default.
/// </summary>
- public int Default { get; set; }
+ public bool Default { get; set; }
/// <summary>
/// Gets or sets the file format.
@@ -72,19 +72,24 @@ namespace HandBrake.ApplicationServices.Interop.Json.Presets
public bool Folder { get; set; }
/// <summary>
- /// Gets or sets the mp 4 http optimize.
+ /// Gets or sets a value indicating whether folder open.
+ /// </summary>
+ public bool FolderOpen { get; set; }
+
+ /// <summary>
+ /// Gets or sets a value indicating whether mp 4 http optimize.
/// </summary>
- public int Mp4HttpOptimize { get; set; }
+ public bool Mp4HttpOptimize { get; set; }
/// <summary>
- /// Gets or sets the mp 4 i pod compatible.
+ /// Gets or sets a value indicating whether mp 4 i pod compatible.
/// </summary>
- public int Mp4iPodCompatible { get; set; }
+ public bool Mp4iPodCompatible { get; set; }
/// <summary>
- /// Gets or sets the picture auto crop.
+ /// Gets or sets a value indicating whether picture auto crop.
/// </summary>
- public int PictureAutoCrop { get; set; }
+ public bool PictureAutoCrop { get; set; }
/// <summary>
/// Gets or sets the picture bottom crop.
@@ -92,6 +97,26 @@ namespace HandBrake.ApplicationServices.Interop.Json.Presets
public int PictureBottomCrop { get; set; }
/// <summary>
+ /// Gets or sets the picture left crop.
+ /// </summary>
+ public int PictureLeftCrop { get; set; }
+
+ /// <summary>
+ /// Gets or sets the picture right crop.
+ /// </summary>
+ public int PictureRightCrop { get; set; }
+
+ /// <summary>
+ /// Gets or sets the picture top crop.
+ /// </summary>
+ public int PictureTopCrop { get; set; }
+
+ /// <summary>
+ /// Gets or sets the picture dar width.
+ /// </summary>
+ public int PictureDARWidth { get; set; }
+
+ /// <summary>
/// Gets or sets the picture deblock.
/// </summary>
public int PictureDeblock { get; set; }
@@ -99,7 +124,7 @@ namespace HandBrake.ApplicationServices.Interop.Json.Presets
/// <summary>
/// Gets or sets the picture decomb.
/// </summary>
- public int PictureDecomb { get; set; }
+ public string PictureDecomb { get; set; }
/// <summary>
/// Gets or sets the picture decomb custom.
@@ -107,14 +132,14 @@ namespace HandBrake.ApplicationServices.Interop.Json.Presets
public string PictureDecombCustom { get; set; }
/// <summary>
- /// Gets or sets the picture decomb deinterlace.
+ /// Gets or sets a value indicating whether picture decomb deinterlace.
/// </summary>
- public int PictureDecombDeinterlace { get; set; }
+ public bool PictureDecombDeinterlace { get; set; }
/// <summary>
/// Gets or sets the picture deinterlace.
/// </summary>
- public int PictureDeinterlace { get; set; }
+ public string PictureDeinterlace { get; set; }
/// <summary>
/// Gets or sets the picture deinterlace custom.
@@ -132,9 +157,19 @@ namespace HandBrake.ApplicationServices.Interop.Json.Presets
public string PictureDenoiseFilter { get; set; }
/// <summary>
+ /// Gets or sets the picture denoise preset.
+ /// </summary>
+ public string PictureDenoisePreset { get; set; }
+
+ /// <summary>
+ /// Gets or sets the picture denoise tune.
+ /// </summary>
+ public string PictureDenoiseTune { get; set; }
+
+ /// <summary>
/// Gets or sets the picture detelecine.
/// </summary>
- public int PictureDetelecine { get; set; }
+ public string PictureDetelecine { get; set; }
/// <summary>
/// Gets or sets the picture detelecine custom.
@@ -142,19 +177,19 @@ namespace HandBrake.ApplicationServices.Interop.Json.Presets
public string PictureDetelecineCustom { get; set; }
/// <summary>
- /// Gets or sets the picture height.
+ /// Gets or sets a value indicating whether picture itu par.
/// </summary>
- public int PictureHeight { get; set; }
+ public bool PictureItuPAR { get; set; }
/// <summary>
- /// Gets or sets the picture keep ratio.
+ /// Gets or sets a value indicating whether picture keep ratio.
/// </summary>
- public int PictureKeepRatio { get; set; }
+ public bool PictureKeepRatio { get; set; }
/// <summary>
- /// Gets or sets the picture left crop.
+ /// Gets or sets a value indicating whether picture loose crop.
/// </summary>
- public int PictureLeftCrop { get; set; }
+ public bool PictureLooseCrop { get; set; }
/// <summary>
/// Gets or sets the picture modulus.
@@ -167,14 +202,19 @@ namespace HandBrake.ApplicationServices.Interop.Json.Presets
public string PicturePAR { get; set; }
/// <summary>
- /// Gets or sets the picture right crop.
+ /// Gets or sets the picture par width.
/// </summary>
- public int PictureRightCrop { get; set; }
+ public int PicturePARWidth { get; set; }
/// <summary>
- /// Gets or sets the picture top crop.
+ /// Gets or sets the picture par height.
/// </summary>
- public int PictureTopCrop { get; set; }
+ public int PicturePARHeight { get; set; }
+
+ /// <summary>
+ /// Gets or sets the picture rotate.
+ /// </summary>
+ public int PictureRotate { get; set; }
/// <summary>
/// Gets or sets the picture width.
@@ -182,6 +222,21 @@ namespace HandBrake.ApplicationServices.Interop.Json.Presets
public int PictureWidth { get; set; }
/// <summary>
+ /// Gets or sets the picture height.
+ /// </summary>
+ public int PictureHeight { get; set; }
+
+ /// <summary>
+ /// Gets or sets the picture force height.
+ /// </summary>
+ public int PictureForceHeight { get; set; }
+
+ /// <summary>
+ /// Gets or sets the picture force width.
+ /// </summary>
+ public int PictureForceWidth { get; set; }
+
+ /// <summary>
/// Gets or sets the preset description.
/// </summary>
public string PresetDescription { get; set; }
@@ -197,9 +252,9 @@ namespace HandBrake.ApplicationServices.Interop.Json.Presets
public int Type { get; set; }
/// <summary>
- /// Gets or sets the uses picture filters.
+ /// Gets or sets a value indicating whether uses picture filters.
/// </summary>
- public int UsesPictureFilters { get; set; }
+ public bool UsesPictureFilters { get; set; }
/// <summary>
/// Gets or sets the uses picture settings.
@@ -207,9 +262,54 @@ namespace HandBrake.ApplicationServices.Interop.Json.Presets
public int UsesPictureSettings { get; set; }
/// <summary>
+ /// Gets or sets a value indicating whether subtitle add cc.
+ /// </summary>
+ public bool SubtitleAddCC { get; set; }
+
+ /// <summary>
+ /// Gets or sets a value indicating whether subtitle add foreign audio search.
+ /// </summary>
+ public bool SubtitleAddForeignAudioSearch { get; set; }
+
+ /// <summary>
+ /// Gets or sets a value indicating whether subtitle add foreign audio subtitle.
+ /// </summary>
+ public bool SubtitleAddForeignAudioSubtitle { get; set; }
+
+ /// <summary>
+ /// Gets or sets the subtitle burn behavior.
+ /// </summary>
+ public string SubtitleBurnBehavior { get; set; }
+
+ /// <summary>
+ /// Gets or sets a value indicating whether subtitle burn bd sub.
+ /// </summary>
+ public bool SubtitleBurnBDSub { get; set; }
+
+ /// <summary>
+ /// Gets or sets a value indicating whether subtitle burn dvd sub.
+ /// </summary>
+ public bool SubtitleBurnDVDSub { get; set; }
+
+ /// <summary>
+ /// Gets or sets the subtitle language list.
+ /// </summary>
+ public List<object> SubtitleLanguageList { get; set; }
+
+ /// <summary>
+ /// Gets or sets the subtitle track selection behavior.
+ /// </summary>
+ public string SubtitleTrackSelectionBehavior { get; set; }
+
+ /// <summary>
/// Gets or sets the video avg bitrate.
/// </summary>
- public string VideoAvgBitrate { get; set; }
+ public int VideoAvgBitrate { get; set; }
+
+ /// <summary>
+ /// Gets or sets the video color matrix code.
+ /// </summary>
+ public int VideoColorMatrixCode { get; set; }
/// <summary>
/// Gets or sets the video encoder.
@@ -227,19 +327,19 @@ namespace HandBrake.ApplicationServices.Interop.Json.Presets
public string VideoFramerateMode { get; set; }
/// <summary>
- /// Gets or sets the video gray scale.
+ /// Gets or sets a value indicating whether video gray scale.
/// </summary>
- public int VideoGrayScale { get; set; }
+ public bool VideoGrayScale { get; set; }
/// <summary>
- /// Gets or sets the video level.
+ /// Gets or sets a value indicating whether video hw decode.
/// </summary>
- public string VideoLevel { get; set; }
+ public bool VideoHWDecode { get; set; }
/// <summary>
- /// Gets or sets the video option extra.
+ /// Gets or sets the video scaler.
/// </summary>
- public string VideoOptionExtra { get; set; }
+ public string VideoScaler { get; set; }
/// <summary>
/// Gets or sets the video preset.
@@ -247,14 +347,24 @@ namespace HandBrake.ApplicationServices.Interop.Json.Presets
public string VideoPreset { get; set; }
/// <summary>
+ /// Gets or sets the video tune.
+ /// </summary>
+ public string VideoTune { get; set; }
+
+ /// <summary>
/// Gets or sets the video profile.
/// </summary>
public string VideoProfile { get; set; }
/// <summary>
- /// Gets or sets the video quality slider.
+ /// Gets or sets the video level.
/// </summary>
- public double VideoQualitySlider { get; set; }
+ public string VideoLevel { get; set; }
+
+ /// <summary>
+ /// Gets or sets the video option extra.
+ /// </summary>
+ public string VideoOptionExtra { get; set; }
/// <summary>
/// Gets or sets the video quality type.
@@ -262,19 +372,29 @@ namespace HandBrake.ApplicationServices.Interop.Json.Presets
public int VideoQualityType { get; set; }
/// <summary>
- /// Gets or sets the video tune.
+ /// Gets or sets the video quality slider.
/// </summary>
- public string VideoTune { get; set; }
+ public double VideoQualitySlider { get; set; }
+
+ /// <summary>
+ /// Gets or sets a value indicating whether video qsv decode.
+ /// </summary>
+ public bool VideoQSVDecode { get; set; }
+
+ /// <summary>
+ /// Gets or sets the video qsv async depth.
+ /// </summary>
+ public int VideoQSVAsyncDepth { get; set; }
/// <summary>
- /// Gets or sets the video turbo two pass.
+ /// Gets or sets a value indicating whether video two pass.
/// </summary>
- public int VideoTurboTwoPass { get; set; }
+ public bool VideoTwoPass { get; set; }
/// <summary>
- /// Gets or sets the video two pass.
+ /// Gets or sets a value indicating whether video turbo two pass.
/// </summary>
- public int VideoTwoPass { get; set; }
+ public bool VideoTurboTwoPass { get; set; }
/// <summary>
/// Gets or sets the x 264 option.
@@ -282,8 +402,8 @@ namespace HandBrake.ApplicationServices.Interop.Json.Presets
public string x264Option { get; set; }
/// <summary>
- /// Gets or sets the x 264 use advanced options.
+ /// Gets or sets a value indicating whether x 264 use advanced options.
/// </summary>
- public int x264UseAdvancedOptions { get; set; }
+ public bool x264UseAdvancedOptions { get; set; }
}
-}
+} \ No newline at end of file
diff --git a/win/CS/HandBrake.ApplicationServices/Interop/Json/Presets/PresetCategory.cs b/win/CS/HandBrake.ApplicationServices/Interop/Json/Presets/PresetCategory.cs
index be31e888e..6700c0a84 100644
--- a/win/CS/HandBrake.ApplicationServices/Interop/Json/Presets/PresetCategory.cs
+++ b/win/CS/HandBrake.ApplicationServices/Interop/Json/Presets/PresetCategory.cs
@@ -22,11 +22,6 @@ namespace HandBrake.ApplicationServices.Interop.Json.Presets
public List<Preset> ChildrenArray { get; set; }
/// <summary>
- /// Gets or sets the default.
- /// </summary>
- public int Default { get; set; }
-
- /// <summary>
/// Gets or sets a value indicating whether folder.
/// </summary>
public bool Folder { get; set; }
@@ -41,4 +36,4 @@ namespace HandBrake.ApplicationServices.Interop.Json.Presets
/// </summary>
public int Type { get; set; }
}
-}
+} \ No newline at end of file
diff --git a/win/CS/HandBrakeWPF/ViewModels/VideoViewModel.cs b/win/CS/HandBrakeWPF/ViewModels/VideoViewModel.cs
index 6252f53f3..47cc4f6a3 100644
--- a/win/CS/HandBrakeWPF/ViewModels/VideoViewModel.cs
+++ b/win/CS/HandBrakeWPF/ViewModels/VideoViewModel.cs
@@ -40,7 +40,7 @@ namespace HandBrakeWPF.ViewModels
public class VideoViewModel : ViewModelBase, IVideoViewModel
{
/*
- * Hard Code "None" in the Models for Tune.t
+ * Hard Code "None" in the Models for Tune.
* Test Everything */
#region Constants and Fields
diff --git a/win/CS/HandBrake.ApplicationServices/Interop/Json/Presets/AudioList.cs b/win/CS/HandBrake.ApplicationServices/Interop/Json/Presets/AudioList.cs
index 8f4670ba5..d77825fa6 100644
--- a/win/CS/HandBrake.ApplicationServices/Interop/Json/Presets/AudioList.cs
+++ b/win/CS/HandBrake.ApplicationServices/Interop/Json/Presets/AudioList.cs
@@ -17,7 +17,17 @@ namespace HandBrake.ApplicationServices.Interop.Json.Presets
/// <summary>
/// Gets or sets the audio bitrate.
/// </summary>
- public string AudioBitrate { get; set; }
+ public int AudioBitrate { get; set; }
+
+ /// <summary>
+ /// Gets or sets the audio compression level.
+ /// </summary>
+ public double AudioCompressionLevel { get; set; }
+
+ /// <summary>
+ /// Gets or sets the audio dither method.
+ /// </summary>
+ public string AudioDitherMethod { get; set; }
/// <summary>
/// Gets or sets the audio encoder.
@@ -30,23 +40,33 @@ namespace HandBrake.ApplicationServices.Interop.Json.Presets
public string AudioMixdown { get; set; }
/// <summary>
+ /// Gets or sets a value indicating whether audio normalize mix level.
+ /// </summary>
+ public bool AudioNormalizeMixLevel { get; set; }
+
+ /// <summary>
/// Gets or sets the audio samplerate.
/// </summary>
public string AudioSamplerate { get; set; }
/// <summary>
- /// Gets or sets the audio track.
+ /// Gets or sets a value indicating whether audio track quality enable.
/// </summary>
- public int AudioTrack { get; set; }
+ public bool AudioTrackQualityEnable { get; set; }
/// <summary>
/// Gets or sets the audio track drc slider.
/// </summary>
- public double AudioTrackDRCSlider { get; set; }
+ public double AudioTrackQuality { get; set; }
/// <summary>
/// Gets or sets the audio track gain slider.
/// </summary>
public double AudioTrackGainSlider { get; set; }
+
+ /// <summary>
+ /// Gets or sets the audio track drc slider.
+ /// </summary>
+ public double AudioTrackDRCSlider { get; set; }
}
-}
+} \ No newline at end of file
@@ -30,23 +40,33 @@ namespace HandBrake.ApplicationServices.Interop.Json.Presets
/// <summary>
- /// Gets or sets the audio track drc slider.
+ /// Gets or sets the audio track quality.
/// </summary>